import { AbstractSigner, Account } from './abstract-signer';
/**
 * A KeyManager lets you import accounts with their private key or PPK (Portable Private Key)
 * and get its address, public key, private key, and sign messages.
 **/
export declare class KeyManager implements AbstractSigner {
    private address;
    private publicKey;
    private privateKey;
    constructor({ address, privateKey, publicKey, }: {
        address: string;
        privateKey: string;
        publicKey: string;
    });
    /**
     * signs a valid hex-string payload with the imported private key.
     * @param {string} payload - The hex payload to sign.
     * @returns {string} - The signed payload as a string.
     * */
    sign(payload: string): Promise<string>;
    /**
     * Creates a new, random Pocket account.
     * @returns {KeyManager} - A new Key Manager instance with the account attached.
     * */
    static createRandom(): Promise<KeyManager>;
    /**
     * Instanciates a new KeyManager from a valid ED25519 private key.
     * @param {string} privateKey - The private key to use to instanciate the new Key manager.
     * @returns {KeyManager} - A new Key Manager instance with the account attached.
     * */
    static fromPrivateKey(privateKey: string): Promise<KeyManager>;
    /**
     * Instanciates a new KeyManager from a valid Portable-Private-Key file.
     * @param {string} password - The password that was used in the PPK.
     * @param {string} ppk - The stringified PPK.
     * @returns {KeyManager} - A new Key Manager instance with the account attached.
     * */
    static fromPPK({ password, ppk, }: {
        password: string;
        ppk: string;
    }): Promise<KeyManager>;
    /**
     * Exports a private key as a Portable-Private-Key, unlockable with the used password.
     * @param {string} password - The password to use in the PPK.
     * @param {string} privateKey - The private key to create the PPK from.
     * @param {string} hint - Password hint.
     * @returns {string} - The PPK in string format.
     * */
    static exportPPK({ privateKey, password, hint, }: {
        privateKey: string;
        password: string;
        hint: string;
    }): Promise<string>;
    /**
     * Validates the PPK json string properties
     * @param {string} jsonStr - JSON String holding the ppk information.
     * @returns {boolean} True or false.
     */
    static validatePPKJSON(jsonStr: string): boolean;
    /**
     * Gets the account address.
     * @returns {string} - The attached account's address.
     * */
    getAddress(): string;
    /**
     * Gets the account public key.
     * @returns {string} - The attached account's public key.
     * */
    getPublicKey(): string;
    /**
     * Gets the account private key.
     * @returns {string} - The attached account's private key.
     * */
    getPrivateKey(): string;
    /**
     * Gets and exports the attached account.
     * @returns {Account} - The attached account.
     * */
    getAccount(): Account;
    /**
     * Exports a private key as a Portable-Private-Key, unlockable with the used password.
     * @param {string} password - The password to use in the PPK.
     * @param {string} hint - Password hint.
     * @returns {string} - The stringified PPK.
     * */
    exportPPK({ password, hint, }: {
        password: string;
        hint?: string;
    }): Promise<string>;
}
//# sourceMappingURL=key-manager.d.ts.map